Learn R Programming

osmose (version 3.3.4)

get_var.osmose.config: get_var method for osmose configuration objects

Description

Get the configuration files from

Usage

# S3 method for osmose.config
get_var(object, what, ...)

Arguments

object

Object of osmose.config class. See the read_osmose and readOsmoseConfiguration functions for more information about this object.

what

Name of the variable to extract from the configuration file.

...

Extra arguments for plotting method.

Value

An object of list class containing all the relevant information about the variable extracted.