Get the configuration files from
# S3 method for osmose.config
get_var(object, what, ...)Object of osmose.config class.
See the read_osmose and readOsmoseConfiguration functions
for more information about this object.
Name of the variable to extract from the configuration file.
Extra arguments for plotting method.
An object of list class containing all the relevant information about
the variable extracted.